diff --git a/doc/api/readline.md b/doc/api/readline.md
index 0251ef178a4..1dbdbe7d2ac 100644
--- a/doc/api/readline.md
+++ b/doc/api/readline.md
@@ -363,9 +363,9 @@ added: v0.1.98
     `crlfDelay` milliseconds, both `\r` and `\n` will be treated as separate
     end-of-line input. Default to `100` milliseconds.
     `crlfDelay` will be coerced to `[100, 2000]` range.
-  * `deDupeHistory` {boolean} If `true`, when a new input line added to the
-    history list duplicates an older one, this removes the older line from the
-    list. Defaults to `false`.
+  * `removeHistoryDuplicates` {boolean} If `true`, when a new input line added
+    to the history list duplicates an older one, this removes the older line
+    from the list. Defaults to `false`.
 
 The `readline.createInterface()` method creates a new `readline.Interface`
 instance.
diff --git a/lib/readline.js b/lib/readline.js
index c2c52c8b737..1ebf6a2c43a 100644
--- a/lib/readline.js
+++ b/lib/readline.js
@@ -39,7 +39,7 @@ function Interface(input, output, completer, terminal) {
 
   EventEmitter.call(this);
   var historySize;
-  var deDupeHistory = false;
+  var removeHistoryDuplicates = false;
   let crlfDelay;
   let prompt = '> ';
 
@@ -49,7 +49,7 @@ function Interface(input, output, completer, terminal) {
     completer = input.completer;
     terminal = input.terminal;
     historySize = input.historySize;
-    deDupeHistory = input.deDupeHistory;
+    removeHistoryDuplicates = input.removeHistoryDuplicates;
     if (input.prompt !== undefined) {
       prompt = input.prompt;
     }
@@ -82,7 +82,7 @@ function Interface(input, output, completer, terminal) {
   this.output = output;
   this.input = input;
   this.historySize = historySize;
-  this.deDupeHistory = !!deDupeHistory;
+  this.removeHistoryDuplicates = !!removeHistoryDuplicates;
   this.crlfDelay = Math.max(kMincrlfDelay,
                             Math.min(kMaxcrlfDelay, crlfDelay >>> 0));
 
@@ -252,7 +252,7 @@ Interface.prototype._addHistory = function() {
   if (this.line.trim().length === 0) return this.line;
 
   if (this.history.length === 0 || this.history[0] !== this.line) {
-    if (this.deDupeHistory) {
+    if (this.removeHistoryDuplicates) {
       // Remove older history line if identical to new one
       const dupIndex = this.history.indexOf(this.line);
       if (dupIndex !== -1) this.history.splice(dupIndex, 1);
diff --git a/test/parallel/test-readline-interface.js b/test/parallel/test-readline-interface.js
index 35b9b393248..59bfb872bee 100644
--- a/test/parallel/test-readline-interface.js
+++ b/test/parallel/test-readline-interface.js
@@ -303,14 +303,14 @@ function isWarned(emitter) {
     return false;
   });
 
   // duplicate lines are removed from history when `options.deDupeHistory`
   // is `true`
   fi = new FakeInput();
   rli = new readline.Interface({
     input: fi,
     output: fi,
     terminal: true,
-    deDupeHistory: true
+    removeHistoryDuplicates: true
   });
   expectedLines = ['foo', 'bar', 'baz', 'bar', 'bat', 'bat'];
   callCount = 0;
@@ -333,14 +333,14 @@ function isWarned(emitter) {
   assert.strictEqual(callCount, 0);
   rli.close();
 
   // duplicate lines are not removed from history when `options.deDupeHistory`
   // is `false`
   fi = new FakeInput();
   rli = new readline.Interface({
     input: fi,
     output: fi,
     terminal: true,
-    deDupeHistory: false
+    removeHistoryDuplicates: false
   });
   expectedLines = ['foo', 'bar', 'baz', 'bar', 'bat', 'bat'];
   callCount = 0;
@@ -303,14 +303,14 @@ function isWarned(emitter) {
   });
 
-  // duplicate lines are removed from history when `options.deDupeHistory`
-  // is `true`
+  // duplicate lines are removed from history when
+  // `options.removeHistoryDuplicates` is `true`
   fi = new FakeInput();
   rli = new readline.Interface({
@@ -333,14 +333,14 @@ function isWarned(emitter) {
   rli.close();
 
-  // duplicate lines are not removed from history when `options.deDupeHistory`
-  // is `false`
+  // duplicate lines are not removed from history when
+  // `options.removeHistoryDuplicates` is `false`
   fi = new FakeInput();
   rli = new readline.Interface({